@@ -25,7 +25,7 @@ from urllib.parse import urlparse
 from unittest.mock import patch
 import posixpath
 
-from datalad_osf.osfclient.osfclient import OSF
+from osfclient import OSF
 
 
 class OSFGitRemote(object):
@@ -55,6 +55,10 @@ class OSFGitRemote(object):
           Stream for logging.
         """
         self.parsed_url = urlparse(url)
+        if self.parsed_url.path and self.parsed_url.path != '/':
+            # project urls have no path
+            raise RuntimeError("Only URLs of type osf://<PROJECT ID> are "
+                               "supported. Got: %s" % url)
         self.remote = remote
         # internal logic relies on workdir to be an absolute path
         self.workdir = Path(gitdir, 'osf', remote).resolve()
@@ -470,15 +474,21 @@ class LZMAZipFile(zipfile.ZipFile):
 
 
 def main():
-    if len(sys.argv) < 3:
-        raise ValueError("Usage: git-remote-osf REMOTE-NAME URL")
+    try:
+        if len(sys.argv) < 3:
+            raise ValueError("Usage: git-remote-osf REMOTE-NAME URL")
 
-    remote, url = sys.argv[1:3]
-    # no fallback, must be present
-    gitdir = os.environ['GIT_DIR']
+        remote, url = sys.argv[1:3]
+        # no fallback, must be present
+        gitdir = os.environ['GIT_DIR']
 
-    osf = OSFGitRemote(gitdir, remote, url)
-    osf.communicate()
+        osf = OSFGitRemote(gitdir, remote, url)
+        osf.communicate()
+    except Exception as e:
+        # Receiving an exception here is "fatal" by definition.
+        # Mimicking git's error reporting style.
+        print("fatal: " + str(e), file=sys.stderr)
+        sys.exit(1)
 
 
 if __name__ == '__main__':
